ScanConfig

Struct ScanConfig 

#[non_exhaustive]
pub struct ScanConfig { /* private fields */ }
Available on crate feature wifi only.
Scan configuration.

Implementations

Source

impl ScanConfig

pub fn ssid(&self) -> Option<Ssid>

SSID to filter for. If [None] is passed, all SSIDs will be returned. If [Some] is passed, only the APs matching the given SSID will be returned.

pub fn with_bssid(self, bssid: [u8; 6]) -> Self

Assign the given value to the bssid field.

pub fn with_bssid_none(self) -> Self

Set the value of bssid to None.

pub fn bssid(&self) -> Option<[u8; 6]>

BSSID to filter for. If [None] is passed, all BSSIDs will be returned. If [Some] is passed, only the APs matching the given BSSID will be returned.

pub fn with_channel(self, channel: u8) -> Self

Assign the given value to the channel field.

pub fn with_channel_none(self) -> Self

Set the value of channel to None.

pub fn channel(&self) -> Option<u8>

Channel to filter for. If [None] is passed, all channels will be returned. If [Some] is passed, only the APs on the given channel will be returned.

pub fn with_show_hidden(self, show_hidden: bool) -> Self

Assign the given value to the show_hidden field.

pub fn show_hidden(&self) -> bool

Whether to show hidden networks.

pub fn with_scan_type(self, scan_type: ScanTypeConfig) -> Self

Assign the given value to the scan_type field.

pub fn scan_type(&self) -> ScanTypeConfig

Scan type, active or passive.

pub fn with_max(self, max: usize) -> Self

Assign the given value to the max field.

pub fn with_max_none(self) -> Self

Set the value of max to None.

pub fn max(&self) -> Option<usize>

The maximum number of networks to return when scanning. If [None] is passed, all networks will be returned. If [Some] is passed, the specified number of networks will be returned.

Source

impl ScanConfig

pub fn with_ssid(self, ssid: impl Into<Ssid>) -> Self

Set the SSID of the access point.

pub fn with_ssid_none(self) -> Self

Clears the SSID.